@@ -50,6 +50,74 @@ AWSSpec = {
             )
         }
     },
+    'dbt2_client': {
+        'count': SpecValidator(
+            type='integer',
+            min=0,
+            max=64,
+            default=1
+        ),
+        'instance_type': SpecValidator(
+            type='choice',
+            choices=[
+                'm5n.xlarge', 'm5n.2xlarge', 'm5n.4xlarge'
+            ] + global_instance_choices,
+            default='m5n.xlarge'
+        ),
+        'volume': {
+            'type': SpecValidator(
+                type='choice',
+                choices=['io1', 'io2', 'gp2', 'gp3', 'st1', 'sc1'],
+                default='gp2'
+            ),
+            'size': SpecValidator(
+                type='integer',
+                min=10,
+                max=16000,
+                default=50
+            ),
+            'iops': SpecValidator(
+                type='integer',
+                min=100,
+                max=64000,
+                default=250
+            )
+        },
+    },
+    'dbt2_driver': {
+        'count': SpecValidator(
+            type='integer',
+            min=0,
+            max=64,
+            default=1
+        ),
+        'instance_type': SpecValidator(
+            type='choice',
+            choices=[
+                'm5n.xlarge', 'm5n.2xlarge', 'm5n.4xlarge'
+            ] + global_instance_choices,
+            default='m5n.xlarge'
+        ),
+        'volume': {
+            'type': SpecValidator(
+                type='choice',
+                choices=['io1', 'io2', 'gp2', 'gp3', 'st1', 'sc1'],
+                default='gp2'
+            ),
+            'size': SpecValidator(
+                type='integer',
+                min=10,
+                max=16000,
+                default=50
+            ),
+            'iops': SpecValidator(
+                type='integer',
+                min=100,
+                max=64000,
+                default=250
+            )
+        },
+    },
     'hammerdb_server': {
         'instance_type': SpecValidator(
             type='choice',
@@ -199,6 +267,97 @@ AWSSpec = {
             )
         }
     },
+    'bdr_server': {
+        'instance_type': SpecValidator(
+            type='choice',
+            choices=[
+                'c5.large', 'c5.xlarge', 'c5.2xlarge', 'c5.4xlarge',
+                'c5.9xlarge', 'c5.12xlarge', 'c5.18xlarge', 'c5.24xlarge',
+                'c5.metal', 'r5n.xlarge', 'r5n.2xlarge', 'r5n.4xlarge',
+                'r5n.8xlarge'
+            ] + global_instance_choices,
+            default='c5.2xlarge'
+        ),
+        'volume': {
+            'type': SpecValidator(
+                type='choice',
+                choices=['io1', 'io2', 'gp2', 'gp3', 'st1', 'sc1'],
+                default='gp2'
+            ),
+            'size': SpecValidator(
+                type='integer',
+                min=10,
+                max=16000,
+                default=50
+            ),
+            'iops': SpecValidator(
+                type='integer',
+                min=100,
+                max=64000,
+                default=250
+            )
+        },
+        'additional_volumes': {
+            'count': SpecValidator(
+                type='integer',
+                min=0,
+                max=5,
+                default=2
+            ),
+            'type': SpecValidator(
+                type='choice',
+                choices=['io1', 'io2', 'gp2', 'gp3', 'st1', 'sc1'],
+                default='gp2'
+            ),
+            'size': SpecValidator(
+                type='integer',
+                min=10,
+                max=16000,
+                default=50
+            ),
+            'iops': SpecValidator(
+                type='integer',
+                min=100,
+                max=64000,
+                default=250
+            ),
+            'encrypted': SpecValidator(
+                type='choice',
+                choices=[True, False],
+                default=False
+            )
+        }
+    },
+    'bdr_witness_server': {
+        'instance_type': SpecValidator(
+            type='choice',
+            choices=[
+                'c5.large', 'c5.xlarge', 'c5.2xlarge', 'c5.4xlarge',
+                'c5.9xlarge', 'c5.12xlarge', 'c5.18xlarge', 'c5.24xlarge',
+                'c5.metal'
+            ] + global_instance_choices,
+            default='c5.xlarge'
+        ),
+        'volume': {
+            'type': SpecValidator(
+                type='choice',
+                choices=['io1', 'io2', 'gp2', 'gp3', 'st1', 'sc1'],
+                default='gp2'
+            ),
+            'size': SpecValidator(
+                type='integer',
+                min=10,
+                max=16000,
+                default=30
+            ),
+            'iops': SpecValidator(
+                type='integer',
+                min=100,
+                max=64000,
+                default=250
+            )
+        }
+    },
     'barman_server': {
         'instance_type': SpecValidator(
             type='choice',
