@@ -5,8 +5,12 @@ from .spec.aws import AWSSpec
 from .spec.aws_rds import AWSRDSSpec
 from .spec.aws_rds_aurora import AWSRDSAuroraSpec
 from .spec.azure import AzureSpec
+from .spec.azure_db import AzureDBSpec
 from .spec.gcloud import GCloudSpec
+from .spec.gcloud_sql import GCloudSQLSpec
 from .spec.baremetal import BaremetalSpec
+from .spec.vmware import VMWareSpec
+from .spec.virtualbox import VirtualBoxSpec
 from .errors import SpecValidatorError
 
 
@@ -98,16 +102,33 @@ def default_spec(cloud, reference_architecture=None):
     """
     if cloud == 'aws':
         return default(AWSSpec)
+    elif cloud == 'aws-pot':
+        # Use same specifications as aws
+        return default(AWSSpec)
     elif cloud == 'aws-rds':
         return default(AWSRDSSpec)
     elif cloud == 'aws-rds-aurora':
         return default(AWSRDSAuroraSpec)
     elif cloud == 'azure':
         return default(AzureSpec)
+    elif cloud == 'azure-pot':
+        # Use same specifications as azure
+        return default(AzureSpec)
+    elif cloud == 'azure-db':
+        return default(AzureDBSpec)
     elif cloud == 'gcloud':
         return default(GCloudSpec)
+    elif cloud == 'gcloud-pot':
+        # Use same specifications as gcloud
+        return default(GCloudSpec)
+    elif cloud == 'gcloud-sql':
+        return default(GCloudSQLSpec)
     elif cloud == 'baremetal':
         return default(BaremetalSpec.get(reference_architecture))
+    elif cloud == 'vmware':
+        return default(VMWareSpec.get(reference_architecture))
+    elif cloud == 'virtualbox':
+        return default(VirtualBoxSpec.get(reference_architecture))
     else:
         return {}
 
@@ -123,10 +144,18 @@ def merge_user_spec(cloud, user_spec, reference_architecture=None):
         cloud_spec = AWSRDSAuroraSpec
     elif cloud == 'azure':
         cloud_spec = AzureSpec
+    elif cloud == 'azure-db':
+        cloud_spec = AzureDBSpec
     elif cloud == 'gcloud':
         cloud_spec = GCloudSpec
+    elif cloud == 'gcloud-sql':
+        cloud_spec = GCloudSQLSpec
     elif cloud == 'baremetal':
         cloud_spec = BaremetalSpec.get(reference_architecture)
+    elif cloud == 'vmware':
+        cloud_spec = VMWareSpec.get(reference_architecture)
+    elif cloud == 'virtualbox':
+        cloud_spec = VirtualBoxSpec.get(reference_architecture)
 
     defaults = default(cloud_spec)
 
